@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014, SUSE LLC
+# Copyright (c) 2014-2015, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -42,11 +42,11 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $meta $site );
-use App::Dochazka qw( $today init_timepiece );
+use App::Dochazka::Common qw( $today init_timepiece );
 use App::Dochazka::REST;
 use App::Dochazka::REST::ConnBank qw( $dbix_conn conn_status );
 use App::Dochazka::REST::ACL qw( check_acl );
-use App::Dochazka::REST::LDAP qw( ldap_exists ldap_auth );
+use App::Dochazka::REST::LDAP qw( ldap_exists ldap_search ldap_auth populate_employee );
 use App::Dochazka::REST::Model::Employee qw( nick_exists );
 use Authen::Passphrase::SaltedDigest;
 use Data::Dumper;
@@ -259,6 +259,7 @@ sub _authenticate {
                         nick => $nick,
                         remark => 'LDAP autocreate',
                     );
+                    populate_employee( $emp );
                     my $faux_context = { 'dbix_conn' => $dbix_conn, 'current' => { 'eid' => 1 } };
                     $status = $emp->insert( $faux_context );
                     if ( $status->not_ok ) {
@@ -266,8 +267,8 @@ sub _authenticate {
                         return $CELL->status_not_ok( 'DOCHAZKA_EMPLOYEE_AUTH' );
                     }
                     $log->notice( "Auto-created employee $nick, who was authenticated via LDAP" );
-                    if ( my $priv = $site->LDAP_LDAP_AUTOCREATE_AS ) {
-                        if ( $priv = 'passerby' ) {
+                    if ( my $priv = $site->DOCHAZKA_LDAP_AUTOCREATE_AS ) {
+                        if ( $priv eq 'passerby' ) {
                             # do nothing
                         } elsif ( $priv =~ m/^(inactive)|(active)$/ ) {
                             init_timepiece();
@@ -282,7 +283,7 @@ sub _authenticate {
                                 " employee ->$nick<- ; reason was " . $status->text )
                                 if $status->not_ok;
                         } else {
-                            $log->error( "Site configuration parameter LDAP_LDAP_AUTOCREATE_AS " .
+                            $log->error( "Site configuration parameter DOCHAZKA_LDAP_AUTOCREATE_AS " .
                                          "is invalid" );
                         }
                     }
